@@ -5,6 +5,7 @@ import sys
 import click
 
 from toolkit.scaffold.project.golang.example import create_example
+from toolkit.scaffold.project.golang.factory import create_factory
 from toolkit.scaffold.project.golang.web import create_web
 
 
@@ -15,6 +16,8 @@ def create_golang_project():
 
 create_golang_project.add_command(create_example, "example")
 
+create_golang_project.add_command(create_factory, "factory")
+
 create_golang_project.add_command(create_web, "web")
 
 if __name__ == "__main__":
